# coding: utf-8

# flake8: noqa

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from client.api.auth_api import AuthApi
from client.api.health_api import HealthApi
from client.api.orders_api import OrdersApi
from client.api.products_api import ProductsApi
from client.api.shops_api import ShopsApi
from client.api.supplier_api import SupplierApi
# import ApiClient
from client.api_client import ApiClient
from client.configuration import Configuration
# import models into sdk package
from client.models.active_order_list_response import ActiveOrderListResponse
from client.models.alternative_products import AlternativeProducts
from client.models.api_response_active_order import ApiResponseActiveOrder
from client.models.api_response_authentication_response import ApiResponseAuthenticationResponse
from client.models.api_response_get_shop_response import ApiResponseGetShopResponse
from client.models.api_response_list_cancel_option_response import ApiResponseListCancelOptionResponse
from client.models.api_response_list_order_response import ApiResponseListOrderResponse
from client.models.api_response_object import ApiResponseObject
from client.models.api_response_order_report_response import ApiResponseOrderReportResponse
from client.models.api_response_order_report_response_wrapper import ApiResponseOrderReportResponseWrapper
from client.models.api_response_pageable_response_shop_products_response import ApiResponsePageableResponseShopProductsResponse
from client.models.api_response_pageable_response_shop_products_response_data import ApiResponsePageableResponseShopProductsResponseData
from client.models.api_response_price_and_quantity_batch_response import ApiResponsePriceAndQuantityBatchResponse
from client.models.api_response_product_batch_ticket_response import ApiResponseProductBatchTicketResponse
from client.models.api_response_shop_couriers_working_status_response import ApiResponseShopCouriersWorkingStatusResponse
from client.models.api_response_shop_working_hours_response import ApiResponseShopWorkingHoursResponse
from client.models.api_response_void import ApiResponseVoid
from client.models.artisan_order_response import ArtisanOrderResponse
from client.models.authentication_response import AuthenticationResponse
from client.models.bag_response import BagResponse
from client.models.cancel_option_response import CancelOptionResponse
from client.models.cancel_order_request import CancelOrderRequest
from client.models.chain_shop_response import ChainShopResponse
from client.models.customer_response import CustomerResponse
from client.models.field_validation import FieldValidation
from client.models.filter_line_order_response import FilterLineOrderResponse
from client.models.filter_order_response import FilterOrderResponse
from client.models.general_error import GeneralError
from client.models.general_error_wrapper import GeneralErrorWrapper
from client.models.get_shop_response import GetShopResponse
from client.models.health_response import HealthResponse
from client.models.internal_error import InternalError
from client.models.internal_error_wrapper import InternalErrorWrapper
from client.models.invoice_address_response import InvoiceAddressResponse
from client.models.invoice_request import InvoiceRequest
from client.models.menu_options_response import MenuOptionsResponse
from client.models.model5001_internal_error import Model5001InternalError
from client.models.name_response import NameResponse
from client.models.operation_result import OperationResult
from client.models.order_dto_response import OrderDtoResponse
from client.models.order_response import OrderResponse
from client.models.packaging_info_response import PackagingInfoResponse
from client.models.packaging_update import PackagingUpdate
from client.models.page_size_invalid_error import PageSizeInvalidError
from client.models.page_size_invalid_error_meta import PageSizeInvalidErrorMeta
from client.models.pageable_response_supplier_product_response import PageableResponseSupplierProductResponse
from client.models.password_reset_request import PasswordResetRequest
from client.models.payment_method_text_response import PaymentMethodTextResponse
from client.models.prepare_order_request import PrepareOrderRequest
from client.models.price_and_quantity_batch_product_response import PriceAndQuantityBatchProductResponse
from client.models.product_batch_request import ProductBatchRequest
from client.models.product_batch_ticket_response import ProductBatchTicketResponse
from client.models.product_batch_vendor_request import ProductBatchVendorRequest
from client.models.product_request import ProductRequest
from client.models.product_response import ProductResponse
from client.models.product_vendor_request import ProductVendorRequest
from client.models.selected_amount import SelectedAmount
from client.models.shop_couriers_working_status_response import ShopCouriersWorkingStatusResponse
from client.models.shop_products_response import ShopProductsResponse
from client.models.shop_response import ShopResponse
from client.models.shop_working_hours_response import ShopWorkingHoursResponse
from client.models.supplier_data_chain_response import SupplierDataChainResponse
from client.models.supplier_data_response import SupplierDataResponse
from client.models.supplier_data_shop_response import SupplierDataShopResponse
from client.models.supplier_product_response import SupplierProductResponse
from client.models.update_shop_couriers_status_request import UpdateShopCouriersStatusRequest
from client.models.update_shop_status_request import UpdateShopStatusRequest
from client.models.update_shop_working_hours_request import UpdateShopWorkingHoursRequest
from client.models.updated_product import UpdatedProduct
